@@ -84,7 +84,7 @@ BEGIN {
 with 'Log::LogMethods';
 with 'Data::Result::Moo';
 }
-our $VERSION='1.020';
+our $VERSION='1.021';
 
 sub BUILD {
   my ($self)=@_;
@@ -204,7 +204,7 @@ has running=>(
 has request_opts=>(
   is=>'rw',
   requires=>1,
-  default=>sub { {cookie_jar=>{},persistent=>0,timeout=>10} },
+  default=>sub { {cookie_jar=>{},persistent=>0} },
 );
 
 has stack=>( is=>'ro');
